@@ -1,17 +1,37 @@
 #!/bin/sh
+# Copyright (C) 2021 David Anderson
+# This test script is in the public domain for use
+# by anyone for any purpose.
+
 start=`date`
 echo "start run-all-tests.sh at $start"
 echo "This removes and recreates /tmp/dw-regression"
-# Use --disable-libelf to turn off all reference to
-# libelf and to also eliminate reliance on dwarfgen.
-# Use --enable-nonstandardprintf to use Windows specific long long
-# printf formats.
+echo "Use --enable-nonstandardprintf to use Windows long long"
+echo "  printf formats."
 # Removes and recreates /tmp/dwtestalldd directory
 # for the regression tests.
+
+chkisdir() {
+  if [ ! -d $1 ]
+  then
+    echo "The directory $1 is not found"
+    echo "we are in the wrong directory to run-all-tests.sh"
+    exit 1
+  fi
+}
 here=`pwd`
-ddsrc=$here/dwarfdump
+ddsrc=$here/src/bin/dwarfdump
 rosrc=$here/../readelfobj/code
 rtestsrc=$here/../regressiontests
+# Sanity checks ensuring we are in the right place.
+chkisdir scripts
+chkisdir $ddsrc
+chkisdir $rtestsrc
+chkisdir $here/src/lib/libdwarf
+chkisdir $here/src/bin/dwarfexample
+chkisdir $here/src/bin/dwarfgen
+chkisdir $here/test
+chkisdir $here/doc
 
 # We run the regression tests here.
 ddtestdir=/tmp/dw-regression
@@ -38,11 +58,8 @@ chkres () {
 while [ $# -ne 0 ]
 do
   case $1 in
-   --enable-libelf ) argval=$1 ; shift ;;
-   --disable-libelf ) argval=$1 ; shift ;;
    --enable-nonstandardprintf ) nonstdprintf=$1 ; shift ;;
-   * ) echo "Only --enable-libelf or --disable-libelf "
-       echo "or --enable-nonstandardprintf allowed."
+   * ) echo "Only  --enable-nonstandardprintf allowed."
        echo "No action taken. Exit"
        exit 1 ;;
   esac
@@ -54,27 +71,25 @@ fi
 
 echo "Starting run-all-tests.sh now"
 echo run from $here
-if [ ! -d $here/dwarfdump ]
+if [ ! -d $here/src/bin/dwarfdump ]
 then
    chkres 1 "A FAIL: This is not the libdwarf 'code' directory "
-   echo "A FAIL: $here/dwarfdump missing. Run from 'code'"
-   exit 0
+   echo "A FAIL: $here/src/bin/dwarfdump missing. Run from 'code'"
+   exit 1
 fi
-if [ ! -d $here/libdwarf ]
+if [ ! -d $here/src/lib/libdwarf ]
 then
   chkres 1 "B FAIL: This is not the libdwarf 'code' directory "
-  echo "B FAIL: $here/libdwarf missing"
+  echo "B FAIL: $here/src/lib/libdwarf missing"
 fi
-if [ ! -d $here/dwarfexample ]
+if [ ! -d $here/src/bin/dwarfexample ]
 then
   chkres 1 "C FAIL: This is not the libdwarf 'code' directory"
-  echo "C FAIL: $here/dwarfexample missing"
-  exit 0
+  echo "C FAIL: $here/src/bin/dwarfexample missing"
+  exit 1
 fi
 
 
-# If we have no libelf we must not attempt to build dwarfgen.
-# FIXME
 # ========
 builddwarfdump() {
   echo "Build dwarfdump source: $here builddir: $ddbld nonstdprintf $nonstdprintf"
@@ -104,12 +119,7 @@ rundistcheck()
   echo "Now rundistcheck"
   cd $here
   chkres $? "Q FAIL: scripts/buildandreleasetest.sh FAIL"
-  if  [ x$1 = "--disable-libelf" ]
-  then
-      sh scripts/buildandreleasetest.sh $1 --disable-dwarfgen $nonstdprintf
-  else
-      sh scripts/buildandreleasetest.sh $1 $nonstdprintf
-  fi
+  sh scripts/buildandreleasetest.sh $1 $nonstdprintf
   chkres $? "R FAIL: scripts/buildandreleasetest.sh FAIL"
   if [ $failcount -eq 0 ]
   then
@@ -168,8 +178,10 @@ runfullddtest() {
   chkres $? "I FAIL: configure in $ddtestdir failed , giving up."
   make
   chkres $? "J FAIL make: tests failed in $ddtestdir. giving up."
+  # Just show the fails, if any.
   grep FAIL <$ddtestdir/ALLdd
-  grep "FAIL 0" $ddtestdir/ALLdd
+  # Now actually check result against the 'PASS' result.
+  grep "FAIL     count: 0" $ddtestdir/ALLdd
   chkres $? "Q FAIL: something failed in $ddtestdir."
   tail -40 $ddtestdir/ALLdd
   if [ $failcount -eq 0 ]
